timerelationtools.timespan_2_starts_when_timespan_1_starts
==========================================================

.. autofunction:: abjad.tools.timerelationtools.timespan_2_starts_when_timespan_1_starts.timespan_2_starts_when_timespan_1_starts
